/*****************************************************************************
 * grab.h: interface to the v4l driver functions and definitions
 *****************************************************************************
 * $Id: grab.h,v 1.6 2003/08/29 23:47:41 alainjj Exp $
 *****************************************************************************
 * Copyright (C) 2001 Keuleu
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************
 *
 * Original code:
 *
 *   (c) 1997,98 Gerd Knorr <kraxel@cs.tu-berlin.de>
 *
 *****************************************************************************/
#ifndef _GRAB_H_
#define _GRAB_H_

#define VIDEO_RGB08          1
#define VIDEO_RGB15          2
#define VIDEO_RGB16          4
#define VIDEO_RGB24          8
#define VIDEO_RGB32         16
#define VIDEO_GRAY          32
#define VIDEO_YUY2          64

#define CAN_AUDIO_VOLUME     1

#define TRAP(txt) fprintf(stderr,"%s:%d:%s\n",__FILE__,__LINE__,txt);exit(1);

extern int debug;
extern int have_dga;

/* ------------------------------------------------------------------------- */

struct device_t {
  char *video;
  char *vbi;
};

struct OVERLAY_CLIP
{
  int x1, x2, y1, y2;
};

struct GRABBER
{
  char *name;
  int video_formats;
  int flags;
  struct STRTAB *norms;
  struct STRTAB *inputs;

  /* open+close */
  int (*grab_open) (struct device_t *opt, int sw, int sh,
            int format, int pixmap, void *base, int bpl);
  int (*grab_close) ();

  int (*grab_overlay) (int x, int y, int width, int height, int format,
               struct OVERLAY_CLIP * oc, int count);

  void *(*grab_scr) (void *dest, int width, int height, int single, int dest_xsize);    /* grab for screen display */
  void *(*grab_one) (int x11_format, int width, int height);    /* snap according to format*/

  int (*grab_tune) (unsigned long freq);
  int (*grab_tuned) (void);
  int (*grab_input) (int input, int norm);
  int (*grab_picture) (int color, int bright, int hue, int contrast);
  int (*grab_audio) (int mute, int volume, int *mode);

  int (*is525) (int norm);
  int (*issecam) (int norm);
  void* (*get_buf)(int i);
};

/* ---------------------------------------------------------------------- */

void grabber_scan(int sw, int sh);

/* nb of seconds since 1/1/1970 of the last video frame
   since double have a 52 bits mantissa,
   the stamp has a precision less than 1 microsecond */
extern double videostampmin,videostampmax;

extern int nbufs_default;

#endif // _GRAB_H_
